<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_ES" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Versión %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 es software libre pero su desarrollo supone un tiempo valioso.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;Haga una donación&lt;/a&gt; para contribuir al desarrollo de %2.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Publicado bajo los términos de la &lt;a href=&apos;%1&apos;&gt;Licencia Pública General de GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Lo que siempre ha querido  saber sobre %1 pero nunca se ha atrevido a preguntar</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>También puede probar mis otras aplicaciones:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, aplicación de YouTube</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, reproductor de música de YouTube</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Traduce %1 a tu idioma utilizando %2</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Comprar en %1</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Leer más</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Leer más</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Volver</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Volver</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bienvenido a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 necesita analizar su colección de música.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Utilizar colección de iTunes</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Utilizar %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Elegir carpeta...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 se conectará a los servicios web de Last.fm y transmitirá los títulos de álbumes y de los intérpretes para buscar carátulas de álbumes, biografías y más información.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Si le preocupa su privacidad, puede omitir este paso.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>¿Dónde está su colección de música?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Seleccione la ubicación de su colección de música.</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Localice su colección</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>Ya se está ejecutando una tarea de análisis</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1 está analizando su colección de música.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1 está utilizando &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; para catalogar su música.</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>Este paso tardará un poco según el tamaño de la colección y de la velocidad de la red.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Tómese un café</translation>
    </message>
</context>
<context>
    <name>DemoStartupView</name>
    <message>
        <source>Please license %1</source>
        <translation>Introduzca la licencia de %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Esta versión de prueba ha caducado.</translation>
    </message>
    <message>
        <source>This demo will expire in %1 days.</source>
        <translation>Días en que caduca esta versión de prueba: %1.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Al adquirir la versión completa, también apoya el gran esfuerzo que pongo en la creación de %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Utilizar versión de prueba</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obtener la versión completa</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>La versión completa permite añadir más de %1 pistas a la lista de reproducción y escuchar su música sin interrupciones.</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Suelte elementos aquí para añadir a la lista de reproducción</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Intérpretes</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Álbumes</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Carpetas</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Reproducir/Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Detener la reproducción al terminar la pista actual</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Pista siguiente</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Pista anterior</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Aumentar volumen</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Disminuir volumen</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Buscar hacia adelante</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Buscar hacia atrás</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation>Se ha producido un error en la autenticación</translation>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation>Inicie sesión en %1</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Nombre de usuario:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Contraseña:</translation>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation>Crear una cuenta de %1</translation>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation>¿Ha olvidado su &lt;a href=&apos;%1&apos;&gt;nombre de usuario&lt;/a&gt; o su &lt;a href=&apos;%2&apos;&gt;contraseña?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Volver</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Vuelve a la vista anterior</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Información</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Muestra información sobre la pista actual</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>&amp;Anterior</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Vuelve a la vista anterior</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Siguiente</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Omitir pista y saltar a la siguiente</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Reproducir</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Comenzar la reproducción</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Ir a pantalla completa</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Q&amp;uitar</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Quita las pistas seleccionadas de la lista de reproducción </translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>S&amp;ubir</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Sube las pistas seleccionadas de la lista de reproducción</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>&amp;Bajar</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Baja las pistas seleccionadas de la lista de reproducción</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Sa&amp;lir</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>¡Hasta luego!</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>&amp;Cambiar carpeta para la colección...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Elija una carpeta diferente para la colección</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Sitio &amp;web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 en la web</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Hacer una &amp;donación</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Contribuya al desarrollo continuo de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Información sobre %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Limpiar</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Quita todas las pistas de la lista de lista de reproducción</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>Alea&amp;torio</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Modo de lista de reproducción al azar</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Repetir</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Reproduce la primera canción de nuevo después de reproducir todas las canciones</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Silenciar volumen</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplicación</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Reproducción</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>&amp;Lista de reproducción</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ay&amp;uda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Pulse %1 para aumentar el volumen, y %2 para disminuirlo</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Abriendo %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Actualizando colección...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Actualizando colección - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Colección actualizada</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Error crítico: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Error: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Salir de pan&amp;talla completa</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tiempo restante: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volumen al %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>El volumen está silenciado</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>El volumen no está silenciado</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obtener la versión completa</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 versión %2 ya está disponible.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Recordarme después</translation>
    </message>
    <message>
        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
        <translation>Para obtener la versión actualizada, descargue %1 de nuevo desde el enlace que recibió por correo, y reinstale.</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ventana completa</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimizar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Comprar %1...</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>&amp;Detener reproducción tras esta pista</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation>&amp;Scrobbling</translation>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation>Enviar temas eproducidos a %1</translation>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation>&amp;Cerrar sesión de %1</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Soltar elementos aquí</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Lista de reproducción terminada</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Esta es solamente una versión de prueba de %1.</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Le permite reproducir algunas pistas para que pueda probar la aplicación y ver si le sirve.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obtener la versión completa</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>La versión de prueba tiene un límite de %1 pistas por lista de reproducciión.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>La lista de reproducción esta vacía</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 pistas - Duración total: %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>No se han obtenido resultados en la búsqueda.</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Pistas</translation>
    </message>
</context>
</TS>